@@ -175,6 +175,7 @@ lefWriteHeader(def, f, lefTech)
     fprintf(f, "   NAMESCASESENSITIVE ON ;\n");
     fprintf(f, "   NOWIREEXTENSIONATPIN ON ;\n");
     fprintf(f, "   DIVIDERCHAR \"/\" ;\n");
+    fprintf(f, "   BUSBITCHARS \"[]\" ;\n");
 
     /* As I understand it, this refers to the scalefactor of the GDS	*/
     /* file output.  Magic does all GDS in nanometers, so the LEF	*/
@@ -739,6 +740,11 @@ lefWriteMacro(def, f, scale)
 	fprintf(f, "   CLASS %s\n", propvalue);
 	class = propvalue;
     }
+    else
+    {
+	/* Needs a class of some kind.  Use BLOCK as default if not defined */
+	fprintf(f, "   CLASS BLOCK\n");
+    }
 
     propvalue = (char *)DBPropGet(def, "LEFsource", &propfound);
     if (propfound)
@@ -1083,6 +1089,9 @@ LefWriteAll(rootUse, writeTopCell, lefTech)
 		lefWriteMacro(def, f, scale);
     }
 
+    /* End the LEF file */
+    fprintf(f, "END LIBRARY ;\n");
+
     fclose(f);
     StackFree(lefDefStack);
 }
